from django.db import models
from django.utils.translation import ugettext_lazy as _

from . import app_settings


class Page(models.Model):
    title = models.CharField(_('title'), max_length=255)
    path = models.CharField(
        _('path'),
        max_length=128,
        unique=True,
        db_index=True,
        help_text=_('Relative URL. Example: <i>/contact/</i>.')
    )
    content = models.TextField(_('content'), blank=True)
    template = models.ForeignKey(
        'Template',
        verbose_name=_('template'),
        default=app_settings.DEFAULT_TEMPLATE_ID
    )

    time_created = models.DateTimeField(_('time created'), auto_now_add=True)
    time_modified = models.DateTimeField(_('time modified'), auto_now=True)

    class Meta:
        verbose_name = _('page')
        verbose_name_plural = _('pages')
        ordering = ('path',)

    def __unicode__(self):
        return u'%s (%s)' % (self.path, self.title)

    def get_absolute_url(self):
        return self.path


class Template(models.Model):
    title = models.CharField(_('title'), max_length=64)
    name = models.CharField(
        _('name'),
        max_length=255,
        help_text=_('Relative path to template. Example: '
                    '<i>paginas/example.html</i>')
    )

    class Meta:
        verbose_name = _('template')
        verbose_name_plural = _('templates')
        ordering = ('title',)

    def __unicode__(self):
        return u'{}'.format(self.title)
